EXPORTS
	??0RSADB@@QAE@XZ @ 1 NONAME ; public: __thiscall RSADB::RSADB(void)
	??0TPfkeyExtAddress@@QAE@ABVTInetAddr@@EEE@Z @ 2 NONAME ; public: __thiscall TPfkeyExtAddress::TPfkeyExtAddress(class TInetAddr const &,unsigned char,unsigned char,unsigned char)
	??0TPfkeyExtIdent@@QAE@ABVTDesC8@@GG@Z @ 3 NONAME ; public: __thiscall TPfkeyExtIdent::TPfkeyExtIdent(class TDesC8 const &,unsigned short,unsigned short)
	??0TPfkeyExtKey@@QAE@ABVTDesC8@@GE@Z @ 4 NONAME ; public: __thiscall TPfkeyExtKey::TPfkeyExtKey(class TDesC8 const &,unsigned short,unsigned char)
	??0TPfkeyExtLifetime@@QAE@KAB_J00ABG@Z @ 5 NONAME ; public: __thiscall TPfkeyExtLifetime::TPfkeyExtLifetime(unsigned long, long long const &, long long const &,long long const &,unsigned short const &)
	??0TPfkeyExtPrivate@@QAE@ABVTDesC8@@@Z @ 6 NONAME ; public: __thiscall TPfkeyExtPrivate::TPfkeyExtPrivate(class TDesC8 const &)
	??0TPfkeyExtSA@@QAE@KEEEEK@Z @ 7 NONAME ; public: __thiscall TPfkeyExtSA::TPfkeyExtSA(unsigned long,unsigned char,unsigned char,unsigned char,unsigned char,unsigned long)
	??0TPfkeyExtSpirange@@QAE@KK@Z @ 8 NONAME ; public: __thiscall TPfkeyExtSpirange::TPfkeyExtSpirange(unsigned long,unsigned long)
	??0TPfkeyRecvMsg@@QAE@ABVTDesC8@@@Z @ 9 NONAME ; public: __thiscall TPfkeyRecvMsg::TPfkeyRecvMsg(class TDesC8 const &)
	??0TPfkeyRecvMsg@@QAE@XZ @ 10 NONAME ; public: __thiscall TPfkeyRecvMsg::TPfkeyRecvMsg(void)
	??0TPfkeySendMsgBase@@QAE@EEHH@Z @ 11 NONAME ; public: __thiscall TPfkeySendMsgBase::TPfkeySendMsgBase(unsigned char,unsigned char,int,int)
	??0TPfkeySendMsgBase@@QAE@XZ @ 12 NONAME ; public: __thiscall TPfkeySendMsgBase::TPfkeySendMsgBase(void)
	??1RSADB@@QAE@XZ @ 13 NONAME ; public: __thiscall RSADB::~RSADB(void)
	?AddExt@TPfkeySendMsgBase@@QAEHABVTPfkeyAnyExt@@ABVTDesC8@@@Z @ 14 NONAME ; public: int __thiscall TPfkeySendMsgBase::AddExt(class TPfkeyAnyExt const &,class TDesC8 const &)
	?BytesUnparsed@TPfkeyRecvMsg@@QAEHXZ @ 15 NONAME ; public: int __thiscall TPfkeyRecvMsg::BytesUnparsed(void)
	?CancelRecv@RSADB@@QAEXXZ @ 16 NONAME ; public: void __thiscall RSADB::CancelRecv(void)
	?Close@RSADB@@QAEXXZ @ 17 NONAME ; public: void __thiscall RSADB::Close(void)
	?Finalize@TPfkeySendMsgBase@@QAEXXZ @ 18 NONAME ; public: void __thiscall TPfkeySendMsgBase::Finalize(void)
	?FinalizeAndSend@RSADB@@QAEXAAVTPfkeySendMsgBase@@AAVTRequestStatus@@@Z @ 19 NONAME ; public: void __thiscall RSADB::FinalizeAndSend(class TPfkeySendMsgBase &,class TRequestStatus &)
	?NextExtension@TPfkeyRecvMsg@@QAEHAAVTPfkeyAnyExt@@@Z @ 20 NONAME ; public: int __thiscall TPfkeyRecvMsg::NextExtension(class TPfkeyAnyExt &)
	?Open@RSADB@@QAEHAAVRSocketServ@@@Z @ 21 NONAME ; public: int __thiscall RSADB::Open(class RSocketServ &)
	?ReadRequest@RSADB@@QAEXAAVTDes8@@AAVTRequestStatus@@@Z @ 22 NONAME ; public: void __thiscall RSADB::ReadRequest(class TDes8 &,class TRequestStatus &)
	?Reset@TPfkeyRecvMsg@@QAEXXZ @ 23 NONAME ; public: void __thiscall TPfkeyRecvMsg::Reset(void)
	?Reset@TPfkeySendMsgBase@@QAEXEEHH@Z @ 24 NONAME ; public: void __thiscall TPfkeySendMsgBase::Reset(unsigned char,unsigned char,int,int)
	?SendRequest@RSADB@@QAEXABVTDesC8@@AAVTRequestStatus@@@Z @ 25 NONAME ; public: void __thiscall RSADB::SendRequest(class TDesC8 const &,class TRequestStatus &)
	?CancelSend@RSADB@@QAEXXZ @ 26 NONAME ; public: void __thiscall RSADB::CancelSend(void)
	??0TPfkeyExtNamedEndPoint@@QAE@ABVTDesC8@@G@Z @ 27 NONAME ; TPfkeyExtNamedEndPoint::TPfkeyExtNamedEndPoint(class TDesC8 const &, unsigned short)
	??0TPfkeyExtTrafficSelector@@QAE@K@Z @ 28 NONAME ; TPfkeyExtTrafficSelector::TPfkeyExtTrafficSelector(unsigned long)
	?SetOpt@RSADB@@QAEXIIABVTDesC8@@@Z @ 29 NONAME ; void RSADB::SetOpt(unsigned int, unsigned int, class TDesC8 const &)

